@@ -2,6 +2,7 @@
 
 # PYTHON IMPORTS
 import operator
+import json
 from functools import reduce
 
 # DJANGO IMPORTS
@@ -15,12 +16,6 @@ from django.utils.encoding import smart_text
 from django.core.exceptions import PermissionDenied
 from django.contrib.admin.util import prepare_lookup_value
 
-# try to use json (2.6+) but stay compatible with 2.5.*
-try:
-    import json
-except ImportError:
-    from django.utils import simplejson as json
-
 # GRAPPELLI IMPORTS
 from grappelli.settings import AUTOCOMPLETE_LIMIT, AUTOCOMPLETE_SEARCH_FIELDS
 
@@ -61,7 +56,7 @@ class RelatedLookup(View):
         if query_string:
             for item in query_string.split(":"):
                 k, v = item.split("=")
-                if k != "t":
+                if k != "_to_field":
                     filters[smart_text(k)] = prepare_lookup_value(smart_text(k), smart_text(v))
         return qs.filter(**filters)
 
